@@ -13,7 +13,6 @@ SETTINGS_RULES = {
         "JWT_VERIFY_EXPIRATION": "bool",
         "JWT_REFRESH_ENABLED": "bool",
         "JWT_BLACKLIST_ENABLED": "bool",
-        "JWT_BLACKLIST_TOKEN_CHECKS": "json.loads"
     },
 }
 
@@ -25,6 +24,7 @@ JWT_VERIFY_EXPIRATION = True
 JWT_PREFIX = "JWT"
 JWT_EXPIRATION_DELTA = timedelta(seconds=60 * 5)
 JWT_REFRESH_EXPIRATION_DELTA = timedelta(days=7)
+JWT_FRESH_DELTA = timedelta(seconds=15)
 JWT_REFRESH_ENABLED = True
 JWT_AUDIENCE = None
 JWT_ISSUER = None
@@ -35,6 +35,12 @@ JWT_JTI_SIZE = 16
 
 JWT_ALGORITHM = "ES256"
 
+JWT_ENCRYPT = False
+JWE_ALGORITHM = "A256KW"
+JWE_ENCRYPTION = "A256CBC-HS512"
+
+AUTH_USER_MODEL_TABLENAME = None
+
 # JWT_ACCESS_LOCATION = "headers"
 # JWT_REFRESH_LOCATION = "headers"
 # JWT_ACCESS_COOKIE_NAME = "access_token"
