@@ -1,5 +1,6 @@
 class ImproperlyConfigured(Exception):
-    """Trubulette is somehow improperly configured"""
+    """Trubulette is somehow improperly configured."""
+
     def __init__(self, message):
         self.message = message
         super().__init__(message)
