@@ -2,7 +2,7 @@ from random import SystemRandom
 
 
 def get_random_string(size: int, allowed_chars: tuple):
-    """Generate a cryptographically random string
+    """Generate a cryptographically random string.
 
     From this answer :
     https://stackoverflow.com/a/23728630/10735573
@@ -13,7 +13,4 @@ def get_random_string(size: int, allowed_chars: tuple):
     Returns:
         (string): The random string
     """
-    return "".join(
-        SystemRandom().choice(allowed_chars)
-        for _ in range(size)
-    )
+    return "".join(SystemRandom().choice(allowed_chars) for _ in range(size))
